Crate sword_core

Crate sword_core 

Modules

error

Macros

inventory_submit
sword_error

Structs

ApplicationConfig
Configuration structure for the Sword application.
ByteConfig
Byte size configuration with raw string representation
ComponentRegistry
Config
ConfigRegistrar
A struct that holds a function to register a config type. Used by the inventory system to collect all config types at compile time.
ControllerRegistry
Registry for managing and storing different controller kinds.
DependencyContainer
A container for managing dependencies and their builders.
EngineBuildContext
Context passed from ‘ApplicationBuilder’ to engine-specific builders.
InterceptorRegistrar
LayerStack
A stack for managing and applying middleware layers to a router.
ProviderRegistry
State
Application state container for type-safe dependency injection and data sharing.
TimeConfig
Time duration configuration with raw string representation

Enums

ConfigSourceInfo
Controller
Controller enum used by #[controller(...)] attributes and runtime internals.
DependencyInjectionError
EventSource
Event source enum used by #[controller(kind = Controller::EventHandler, ...)] attributes and runtime internals to select which event backend a handler consumes from.

Traits

Build
Base trait for any component that can be constructed from the application State.
Component
Trait for injectable components that can be automatically constructed by the dependency container with automatic dependency resolution.
ConfigItem
Trait for configuration section types.
ControllerSpec
A trait for defining controllers in the application.
HasDeps
Trait for components that have dependencies on other components.
Interceptor
Base trait for all interceptors in Sword. Implement this trait to create interceptors that can be automatically registered and built via the dependency injection system.
Module
A trait for defining modules in the application.
Provider
Marker trait for pre-instantiated dependencies (providers).

Functions

shutdown_signal
Waits for a shutdown signal (SIGINT or SIGTERM) and logs which signal was received.

Type Aliases

ControllerIds
ControllerMap