Module layers

Module layers 

Modules

cookie
HTTP cookie parsing and cookie jar management.
service
Middleware to use Cookies.

Structs

BodyLimitConfig
Body Limit Configuration
BodyLimitLayer
Body Limit Layer
CompressionConfig
Compression Configuration
CompressionLayer
Compression Layer
Cookie
Representation of an HTTP cookie.
CookieManager
Middleware to use Cookies.
CookieManagerLayer
Layer to apply CookieManager middleware.
Cookies
A parsed on-demand cookie jar.
CorsConfig
CORS Configuration
CorsLayer
CORS Layer
Key
A cryptographic master key for use with Signed and/or Private jars.
LayerStack
A stack for managing and applying middleware layers to a router.
MiddlewaresConfig
NotFoundLayer
PrivateCookies
A cookie jar that provides authenticated encryption for its cookies.
RequestId
An identifier for a request.
RequestIdLayer
RequestTimeoutConfig
Request Timeout Configuration
RequestTimeoutLayer
Request Timeout Layer
ServeDirConfig
Serve Directory Configuration
ServeDirLayer
Serve Directory Layer
SignedCookies
A child cookie jar that authenticates its cookies. It signs all the cookies added to it and verifies cookies retrieved from it. Any cookies stored in SignedCookies are provided integrity and authenticity. In other words, clients cannot tamper with the contents of a cookie nor can they fabricate cookie values, but the data is visible in plaintext.
Uuid
A Universally Unique Identifier (UUID).

Traits

DisplayConfig

Type Aliases

ResponseFnMapperServiceLayer