pub struct ServeDirLayer;Expand description
Serve Directory Layer
This struct represents the Serve Directory Layer which serves static files and directories.
The layer is a wrapper around tower_http::services::ServeDir.
Serves static content with optional compression and custom chunk sizing.
Implementations
Sourceimpl ServeDirLayer
impl ServeDirLayer
pub fn new(config: &ServeDirConfig) -> ServeDir<ServeFile>