LayerStack

Struct LayerStack 

pub struct LayerStack<S> { /* private fields */ }
A stack for managing and applying middleware layers to a router.

LayerStack provides a way to accumulate layers and apply them to a router in the order they were added. Layers are applied via the push() method during configuration, and then applied to the router via apply() during the build phase.

Implementations

Source

impl<S> LayerStack<S>
where S: Clone + Send + Sync + 'static,

pub fn new() -> Self

pub fn push<L>(&mut self, layer: L)
where L: Layer<Route> + Clone + Send + Sync + 'static, L::Service: Service<Request> + Clone + Send + Sync + 'static, <L::Service as Service<Request>>::Response: IntoResponse + 'static, <L::Service as Service<Request>>::Error: Into<Infallible> + 'static, <L::Service as Service<Request>>::Future: Send + 'static,

Add a layer to the stack.

Layers are applied in FIFO order when apply() is called. Each layer will wrap the router after all controllers have been registered.

pub fn apply(&self, router: Router<S>) -> Router<S>

Apply all layers to the given router.

Layers are applied in FIFO order (first pushed = first applied = outermost).