pub trait Component: HasDeps { }Expand description
Trait for injectable components that can be automatically constructed by the dependency container with automatic dependency resolution.
Components are services or dependencies that need to be built from other components in the State.
Use the #[injectable] macro to automatically implement this trait.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".