pub struct RequestTimeoutLayer;Expand description
Request Timeout Layer
This struct represents the Request Timeout Layer which enforces a maximum duration for incoming requests.
The layer is a combination of tower_http::timeout::TimeoutLayer and a response mapper.
Returns a 408 Request Timeout status when a request exceeds the configured duration.
Implementations
Sourceimpl RequestTimeoutLayer
impl RequestTimeoutLayer
pub fn new( config: &RequestTimeoutConfig, ) -> (TimeoutLayer, ServiceBuilder<Stack<MapResponseLayer<fn(Response<Body>) -> Response<Body>>, Identity>>)